/* headings */
.elfinder .elfinder-cwd table thead tr {
  background: none;
  border: none;
}
.elfinder .elfinder-cwd table thead tr td,
.elfinder .elfinder-cwd table thead tr td.ui-state-active {
  font-weight: bold;
  font-size: 13px;
  position: relative;

  color: #474747;
  text-shadow: 0 1px 0 rgba(255,255,255,.75);

  border-bottom: 2px solid #b2b2b2;
  padding: 6px 18px 6px 10px;

  border-radius: 2px 2px 0 0;
  box-shadow: 0 1px 0 #fff inset;

  background: #cfd1cf;
  background-image: linear-gradient(to bottom, #f5f5f5, #cfd1cf);
  filter: progid:DXImageTransform.Microsoft.gradient(gradientType=0, startColorstr='#f5f5f5', endColorstr='#cfd1cf');
}

/* sorter icon */
.elfinder .elfinder-cwd-wrapper-list tr td .ui-icon,
.elfinder .elfinder-cwd-wrapper-list tr.ui-state-default td .ui-icon {
  text-indent: 0;
  background-image: none !important;
  overflow: hidden;
  font-size: 14px;
  line-height: 16px;
  width: 20px;
  text-align: center;
  position: absolute;
  top: 0;
  right: 0;
  height: 100%;
  line-height: 28px;
  margin: auto 0 auto auto;
}

.elfinder .elfinder-cwd-wrapper-list tr td .ui-icon:before {
  font-family: FontAwesome;
  height: 16px;
  height: 100%;
  background: none;
  display: block;
  text-align: center;
}

/* down */
.elfinder .elfinder-cwd-wrapper-list tr.ui-state-default td .ui-icon-triangle-1-s:before {
  content: '\f0d7';
}

/* up */
.elfinder .elfinder-cwd-wrapper-list tr.ui-state-default td .ui-icon-triangle-1-n:before {
  content: '\f0de';
}

/* files */
.elfinder .elfinder-cwd table {
  padding: 0; /* fix for v2.1 */
}

.elfinder .elfinder-cwd table tr * {
  cursor: default;
}

.elfinder .elfinder-cwd table tbody tr:nth-child(odd) { background-color:#eaeaea; }
.elfinder .elfinder-cwd table tbody tr { }

/* fix for font sizes on v2.x */
.elfinder .elfinder-cwd-view-list td { font-size: 12px; }
.elfinder .elfinder-cwd-view-list td div {
  padding-top: 3px;
  padding-bottom: 3px;
}

/* hover state */
.elfinder .elfinder-cwd-wrapper-list .elfinder-cwd-file:hover,
.elfinder .elfinder-cwd-wrapper-list .elfinder-cwd-file.ui-state-hover { /* fix for v2.x */
  background-image: none;
  background: #d0ebf4;
}

/* fix text hover color */
.elfinder .elfinder-cwd-wrapper-list .elfinder-cwd-file:hover *,
.elfinder .elfinder-cwd-wrapper-list .elfinder-cwd-file.ui-state-hover:hover *,
.elfinder .elfinder-cwd-wrapper-list .elfinder-cwd-file.ui-state-hover * { /* fix for v2.x */
  color: #509ece;
}

/* selected files */
.elfinder .elfinder-cwd table tbody tr.ui-selected td {
  background-color: #D2D2D7;
  background-image: none;
}

/* selected files text color */
.elfinder .elfinder-cwd-wrapper-list .elfinder-cwd-file.ui-selected:hover * { color: #fff; }

/* icon size settings */
.elfinder .elfinder-cwd-wrapper-list .elfinder-cwd-icon {
  height: 16px;
  width: 16px;
  font-size: 14px;
  line-height: 16px;
}

.elfinder .elfinder-cwd-wrapper-list .elfinder-cwd-icon:before {

}
