/**
 * Moono CKEditor like theme for elFinder
 * Required jquery ui "smoothness" theme and FontAwesome for icons
 * Style rules copied and edited from Moono CKEditor source
 * @author lokothodida
 **/

/* FontAwesome Icons */
@import url('//maxcdn.bootstrapcdn.com/font-awesome/4.4.0/css/font-awesome.min.css');

/* Main features of the whole UI */
@import url('mainui.less');

/* File Icons */
@import url('file-icons.less');

/* Toolbar  */
@import url('toolbar.less');

/* Toolbar Icons */
@import url('toolbar-icons.less');

/* Navbar */
@import url('navbar.less');

/* Navbar Restrictions */
@import url('navbar-restrict.less');

/* Navbar Icons */
@import url('navbar-icons.less');

/* Thumbnail View */
@import url('view.less');

/* List View */
@import url('view-list.less');

/* View Icons */
@import url('view-icons.less');

/* Modal Dialogs */
@import url('dialog.less');

/* Context menu */
@import url('contextmenu.less');

/* Status Bar */
@import url('statusbar.less');
