<h2>Conseils d'utilisation</h2>
<p>Le fonctionnement sur l&#39;interface utilisateur est similaire &agrave; celui du gestionnaire de fichiers standard du syst&egrave;me d&#39;exploitation. Cependant, le glisser-d&eacute;poser n&#39;est pas possible avec les navigateurs mobiles. </p>
<ul>
<li>Cliquez avec le bouton droit ou appuyez longuement pour afficher le menu contextuel.</li>
<li>Faites glisser et d&eacute;posez dans l&#39;arborescence des dossiers ou dans l&#39;espace de travail actuel pour d&eacute;placer/copier des &eacute;l&eacute;ments.</li>
<li>La s&eacute;lection d&#39;&eacute;l&eacute;ments dans l&#39;espace de travail peut &ecirc;tre une s&eacute;lection &eacute;tendue avec la touche Maj ou Alt (Option).</li>
<li>Faites glisser et d&eacute;posez vers le dossier ou l&#39;espace de travail de destination pour t&eacute;l&eacute;charger des fichiers et des dossiers.</li>
<li>La bo&icirc;te de dialogue de t&eacute;l&eacute;chargement peut accepter le collage/d&eacute;placement de donn&eacute;es du presse-papiers ou de listes d&#39;URL, ainsi que le glisser-d&eacute;poser depuis d&#39;autres navigateurs ou gestionnaires de fichiers, etc.</li>
<li>Faites glisser le d&eacute;but en appuyant sur la touche Alt (Option) pour le faire glisser vers l&#39;ext&eacute;rieur du navigateur. Cela deviendra une op&eacute;ration de t&eacute;l&eacute;chargement avec Google Chrome.</li>
</ul>
