/* main dialog styles */
.elfinder-dialog {
  padding: 0;
  background: #eaeaea;
  border: 1px solid #b2b2b2;
  border-bottom-color: #999;
  border-radius: 3px;
  box-shadow: 0 0 3px rgba(0, 0, 0, .15);
}

/* reset the margin */
.elfinder-dialog .ui-dialog-content,
.elfinder-dialog .ui-dialog-content .ui-tabs {
  padding: 0;
  margin: 0;
  border: 0;
}

/* titlebar */
.elfinder-dialog .ui-dialog-titlebar {
  font-weight: bold;
  font-size: 13px;
  cursor: move;
  position: relative;

  color: #474747;
  text-shadow: 0 1px 0 rgba(255,255,255,.75);

  border-bottom: 1px solid #999;
  padding: 6px 10px;

  border-radius: 2px 2px 0 0;
  box-shadow: 0 1px 0 #fff inset;

  background: #cfd1cf;
  background-image: linear-gradient(to bottom, #f5f5f5, #cfd1cf);
  filter: progid:DXImageTransform.Microsoft.gradient(gradientType=0, startColorstr='#f5f5f5', endColorstr='#cfd1cf');
}

/* icons */
.elfinder-dialog-icon {
  background: none;
  font-size: 18px;
  height: 20px;
  width: 20px;
  overflow: hidden;
  display: block;
  text-align: center;
  line-height: 20px;
  position: relative;
  margin: 0 20px 0 0;
  float: left;
}

.elfinder-dialog-icon:before {
  font-family: FontAwesome;
  background: none;
  display: block;
  text-align: center;
  cursor: pointer;
}

.elfinder-dialog-icon-error:before { content: '\f06a'; }
.elfinder-dialog-icon-confirm:before { content: '\f059'; }

/* tabs navigation backdrop */
.elfinder-dialog .ui-tabs-nav {
  height: 24px;
  background: #eaeaea;
  border: 0;
  border-bottom: 1px solid #999;
  border-radius: 0;
}

/* regular tab */
.elfinder-dialog .ui-tabs .ui-tabs-nav li a {
  display: block;
  padding: 3px;
  border: none;
  outline: none;
}

.elfinder-dialog .ui-tabs-nav .ui-state-default {
  height: 16px;
  padding: 3px;
  margin-right: 3px;
  display: inline-block;
  cursor: pointer;
  line-height: 16px;
  outline: none;
  color: #595959;
  border: 1px solid #bfbfbf;

  border-radius: 3px 3px 0 0;

  background: #d4d4d4;
  background-image: linear-gradient(to bottom, #fafafa, #ededed);
  filter: progid:DXImageTransform.Microsoft.gradient(gradientType=0, startColorstr='#fafafa', endColorstr='#ededed');
}

/* selected tab */
.elfinder-dialog .ui-tabs-nav .ui-tabs-selected {
  background: #fff;
  color: #383838;
  border-bottom-color: #fff;
  cursor: default;
  filter: none;
  padding-bottom: 4px !important;
}

/* active tab */
.elfinder-dialog .ui-tabs-nav li:active {
  background: #ededed;
  background: linear-gradient(to bottom, #ededed 0%,#ffffff 100%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#ededed', endColorstr='#ffffff',GradientType=0 );
}

/* info dialog */
.elfinder-dialog .elfinder-cwd-icon {
  background-image: none !important;
  overflow: hidden;
  height: 52px;
  width: 52px;
  font-size: 48px;
  line-height: 52px;
  margin: 6px;
}

/* file upload dialog */
.elfinder-dialog .elfinder-upload-dropbox,
.elfinder-dialog .elfinder-upload-dialog-or,
.elfinder-dialog .ui-button.ui-button-text-only {
  margin: 6px;
  text-align: center;
}

/* file editing dialog */
.elfinder-dialog .elfinder-file-edit {
  box-sizing: border-box;
  width: 100%;
  height: 100%;
  border: 0;
  padding: 5px;
}

/* error dialog */
.elfinder-dialog-error .ui-dialog-content,
.elfinder-dialog-confirm .ui-dialog-content {
  white-space: normal;
  padding: 5px;
}

/* disable resizing on textarea */
.elfinder-dialog textarea {
  resize: none;
}

/* footer */
.elfinder-dialog .ui-dialog-buttonpane {
  text-align: right;
  position: relative;
  border: none;
  outline: 1px solid #bfbfbf;
  box-shadow: 0 1px 0 #fff inset;
  border-radius: 0 0 2px 2px;
  background: #cfd1cf;
  background-image: linear-gradient(to bottom, #ebebeb, #cfd1cf);
  filter: progid:DXImageTransform.Microsoft.gradient(gradientType=0, startColorstr='#ebebeb', endColorstr='#cfd1cf');
}

/* buttons */
.elfinder-dialog .ui-dialog-buttonset {
  margin-right: 8px;
}

.elfinder-dialog .ui-button {
  display: inline-block;
  *display: inline;
  *zoom: 1;

  padding: 4px 0;
  margin: 0 0 4px 4px !important;

  text-align: center;
  color: #333;
  vertical-align: middle;
  cursor: pointer;

  border: 1px solid #b6b6b6;
  border-bottom-color: #999;
  border-radius: 3px;
  box-shadow: 0 1px 0 rgba(255,255,255,.5), 0 0 2px rgba(255,255,255,.15) inset, 0 1px 0 rgba(255,255,255,.15) inset;

  background: #e4e4e4;
  background-image: linear-gradient(to bottom, #ffffff, #e4e4e4);
  filter: progid:DXImageTransform.Microsoft.gradient(gradientType=0, startColorstr='#ffffff', endColorstr='#e4e4e4');
}

.elfinder-dialog .ui-button:hover {
  border-color: #9e9e9e;

  background: #ccc;
  background-image: linear-gradient(to bottom, #f2f2f2, #ccc);
  filter: progid:DXImageTransform.Microsoft.gradient(gradientType=0, startColorstr='#f2f2f2', endColorstr='#cccccc');
}

.elfinder-dialog .ui-button:active {
  border-color: #969696;
  outline: none;
  box-shadow: 0 0 6px rgba(0,0,0,.4) inset;
}
