.elfinder .elfinder-navbar {
  background: #fff;
}

/* directory */
.elfinder .elfinder-navbar-dir {
  padding: 3px 3px 3px 38px; /* push the text away from the icon */
  margin: 0 0 3px 0;
  display: block;
  overflow: hidden;
  cursor: pointer;
}

/* active directory */
.elfinder .elfinder-navbar-dir.ui-state-active {
  border: 1px solid #a6a6a6;
  border-bottom-color: #979797;
  color: #000; /* fix for 2.x */
  border-radius: 3px;
  box-shadow: 0 1px 0 rgba(255,255,255,.5), 0 0 2px rgba(255,255,255,.15) inset, 0 1px 0 rgba(255,255,255,.15) inset;
  background: #e4e4e4;
  background-image: linear-gradient(to bottom, #ffffff, #e4e4e4);
  filter: progid:DXImageTransform.Microsoft.gradient(gradientType=0, startColorstr='#ffffff', endColorstr='#e4e4e4');
  }

.elfinder .elfinder-navbar-dir:hover {
  border: 1px solid #a6a6a6;
  border-bottom-color: #979797;
  border-radius: 3px;
  box-shadow: 0 1px 0 rgba(255,255,255,.5), 0 0 2px rgba(255,255,255,.15) inset, 0 1px 0 rgba(255,255,255,.15) inset;
  background: #e4e4e4;
  background-image: linear-gradient(to bottom, #ffffff, #e4e4e4);
  filter: progid:DXImageTransform.Microsoft.gradient(gradientType=0, startColorstr='#ffffff', endColorstr='#e4e4e4');
}
